Name:           cid
Version:        1.2.1
Release:        %mkrel 1
Summary:        Bash scripts to insert and manage a Linux computer in an AD domain

License:        GPLv3+
URL:            https://c-i-d.sourceforge.io
Source0:        http://downloads.sf.net/c-i-d/%{name}-%{version}.tar.gz

Patch0:         cid-gtk.desktop.patch
Patch1:         cid-change-pass-gtk.desktop.patch

Requires:       acl attr cifs-utils cups iproute2 iputils keyutils krb5-workstation pam_mount samba samba-client samba-winbind samba-winbind-clients sudo xhost zenity

BuildArch:      noarch

%description
CID (Closed In Directory) is a set of bash scripts for inserting and
managing Linux computers in Active Directory domains. Modifications
made to the system allow Linux to behave like a Windows computer within AD.

You can do things like:

- Run logon scripts;
- Automatically mount network shares (files and printers);
- Offline logon (Credential cache);
- Easily grant privileges to domain users (eg: access to the sudo command);
- Manage Samba shares (files and printers) through a graphical interface;
- Apply disk quota per shared directory (such as Windows Server).

%prep
%setup -q
%patch0 -p0
%patch1 -p0
%build

%install
%global _sharedir %{buildroot}/usr/share
%global _vardir %{buildroot}/var
CONFDIR="%{buildroot}/%{_sysconfdir}/%{name}"
TEMPDIR=/tmp/.%{name}
BINDIR="%{buildroot}/%{_bindir}"
SBINDIR="%{buildroot}/%{_sbindir}"
BASHCOMPDIR="%{_sharedir}/bash-completion/completions"
POLKITDIR="%{_sharedir}/polkit-1/actions"
APPSDIR="%{_sharedir}/applications"
MAN8DIR="%{buildroot}/%{_mandir}/man8"
MAN1DIR="%{buildroot}/%{_mandir}/man1"
DOCDIR="%{buildroot}/%{_docdir}/%{name}-base"
SHAREDIR="%{_sharedir}/%{name}"
SCRIPTDIR="${SHAREDIR}/scripts"
MODELDIR="${SHAREDIR}/templates"
ICONDIR="${SHAREDIR}/icons"
LOGDIR="%{_vardir}/log/%{name}"
VARLIBDIR="%{_vardir}/lib/%{name}"
DBDIR="${VARLIBDIR}/databases"
BACKUPDIR="${VARLIBDIR}/backups/ori"
RESTOREDIR="${VARLIBDIR}/backups/mod"
VAR='LOGDIR DBDIR BACKUPDIR RESTOREDIR'

FILE="${MODELDIR}/scripts_cid/logon_root.sh
${MODELDIR}/scripts_cid/logon.sh
${MODELDIR}/scripts_cid/shares.xml
${SCRIPTDIR}/change_pass.bash
${SCRIPTDIR}/logon_commonUser.bash
${SCRIPTDIR}/mkhomedir.bash
${SCRIPTDIR}/functions.bash
${SCRIPTDIR}/pre_logon.bash
${SCRIPTDIR}/logon_superUser.bash
${SCRIPTDIR}/umount_netlogon.bash
${SCRIPTDIR}/logger.bash
${SCRIPTDIR}/manager_systemGroups.bash
${SCRIPTDIR}/setquota.bash
${SCRIPTDIR}/vars.bash
${ICONDIR}/cid-cp.png
${ICONDIR}/cid.png
${SHAREDIR}/cid.bash
${SHAREDIR}/cid_gtk.bash
${SBINDIR}/cid-gtk
${CONFDIR}/cid.conf.example
${BASHCOMPDIR}/cid
${DOCDIR}/COPYING
${DOCDIR}/README
${APPSDIR}/cid-gtk.desktop
${APPSDIR}/cid-change-pass-gtk.desktop
${POLKITDIR}/org.freedesktop.cid.policy
${MAN8DIR}/cid.8
${MAN8DIR}/cid-gtk.8
${MAN1DIR}/cid-change-pass.1
${MAN1DIR}/cid-change-pass-gtk.1"

for file in $FILE; do
	[ ! -d "${file%/*}" ] && mkdir -p "${file%/*}"

	find -type f -name "${file##*/}" -exec cp -f {} "$file" \;

	[ "${file%/*}" = "$SBINDIR" -o "${file##*.}" = "sh" -o "${file##*.}" = "bash" ] && chmod +x "$file"
	[ "${file##*.}" = "1" -o "${file##*.}" = "8" ] && gzip -f "$file" 2>&1
done

for var in $VAR; do
	[ ! -d "${!var}" ] && mkdir -p "${!var}"
done

%post
unset FQDN

. /usr/share/cid/scripts/vars.bash || true

FILE="${SBINDIR}/%{name}:${SHAREDIR}/%{name}.bash
${BINDIR}/%{name}-change-pass:${SCRIPTDIR}/change_pass.bash
${BINDIR}/%{name}-change-pass-gtk:${SCRIPTDIR}/change_pass.bash"

for file in $FILE; do
	lnk=${file%%:*}
	[ ! -d "${lnk%/*}" ] && mkdir -p "${lnk%/*}"
	ln -sf "${file##*:}" "$lnk"
done

if [ -n "$FQDN" ]; then
	${SCRIPTDIR}/functions.bash reload || true
fi

%postun
FILE="%{_sbindir}/%{name} %{_bindir}/%{name}-change-pass %{_bindir}/%{name}-change-pass-gtk"

for file in $FILE; do
	if [ -L "$file" ]; then
		[ -f "$(readlink -m "$file")" ] || rm -f "$file"
	fi
done

%files
%global _sharedir /usr/share
#%license COPYING
%doc %{_docdir}/%{name}-base
%doc %{_mandir}/man8/%{name}.8.bz2
%doc %{_mandir}/man8/%{name}-gtk.8.bz2
%doc %{_mandir}/man1/%{name}-change-pass*.bz2
%dir /usr/share/%{name}
%dir /var/lib/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf.example
%{_sbindir}/%{name}-gtk
%{_sharedir}/%{name}/cid.bash
%{_sharedir}/%{name}/cid_gtk.bash
%{_sharedir}/%{name}/icons/cid-cp.png
%{_sharedir}/%{name}/icons/cid.png
%{_sharedir}/%{name}/scripts/change_pass.bash
%{_sharedir}/%{name}/scripts/functions.bash
%{_sharedir}/%{name}/scripts/logger.bash
%{_sharedir}/%{name}/scripts/logon_commonUser.bash
%{_sharedir}/%{name}/scripts/logon_superUser.bash
%{_sharedir}/%{name}/scripts/manager_systemGroups.bash
%{_sharedir}/%{name}/scripts/mkhomedir.bash
%{_sharedir}/%{name}/scripts/pre_logon.bash
%{_sharedir}/%{name}/scripts/setquota.bash
%{_sharedir}/%{name}/scripts/umount_netlogon.bash
%{_sharedir}/%{name}/scripts/vars.bash
%{_sharedir}/%{name}/templates/scripts_cid/logon.sh
%{_sharedir}/%{name}/templates/scripts_cid/logon_root.sh
%{_sharedir}/%{name}/templates/scripts_cid/shares.xml
%{_sharedir}/bash-completion/completions/%{name}
%{_sharedir}/applications/%{name}-*.desktop
%{_sharedir}/polkit-1/actions/org.freedesktop.cid.policy

%changelog
* Wed Feb 09 2022 pinoleone <dev@ufficiozero.org> 1.2.1-1ufficiozero2021
- update
* Wed Sep 22 2021 pinoleone <dev@ufficiozero.org> 1.1.6-2ufficiozero2021
- fixed with right %distsuffix
* Tue Sep 14 2021 pinoleone <dev@ufficiozero.org> 1.1.6-2ufficiozero2021
* Fri Sep 10 2021 pinoleone <dev@ufficiozero.org> 1.1.6-1ufficiozero2021
- update
* Thu Aug 03 2021 adrianomorselli <dev@ufficiozero.org> 1.1.5-2ufficiozero2021
- rebuilded

* Sat Jul 31 2021 Eduardo Moraes <emoraes25@gmail.com> - 1.1.5-1
- First cid package
